#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from .interfaces import IImagePortletSettings
from pyams_file.interfaces import IResponsiveImage, DELETED_FILE
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import PUBLIC_PERMISSION

# import packages
from pyams_file.property import FileProperty
from pyams_portal.portlet import portlet_config, Portlet, PortletSettings, PortletRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from zope.interface import implementer, Interface, alsoProvides

from pyams_portal import _


IMAGE_PORTLET_NAME = 'pyams_portal.portlet.image'


@implementer(IImagePortletSettings)
class ImagePortletSettings(PortletSettings):
    """Image portlet settings"""

    _image = FileProperty(IImagePortletSettings['image'])

    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value
        if (value is not None) and (value is not DELETED_FILE):
            alsoProvides(self._image, IResponsiveImage)


@portlet_config(permission=PUBLIC_PERMISSION)
class ImagePortlet(Portlet):
    """Image portlet"""

    name = IMAGE_PORTLET_NAME
    label = _("Image")

    toolbar_image = None
    toolbar_css_class = 'fa fa-fw fa-2x fa-picture-o'

    settings_class = ImagePortletSettings


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IImagePortletSettings), provides=IPortletRenderer)
@template_config(template='image.pt', layer=IPyAMSLayer)
class ImagePortletRenderer(PortletRenderer):
    """Image portlet renderer"""

    label = _("Responsive image renderer")
